@@ -9,15 +9,17 @@ from rsack.utils import Settings, sanitize
 
 class Download():
     def __init__(self, url):
-        self.client = KkboxAPI()
         self.settings = Settings().KKBox()
         self.id = url.split("/")[-1]
+        self.client = KkboxAPI(proxy=self.settings['proxy'])
         self.client.login(email=self.settings['email'],
                             password=self.settings['password'],
-                            region_bypass=True)
+                            region_bypass=False)
         if url.split("/")[-2] == "artist":
             artist = self.client.get_artist(self.id)
-            for album in artist['album']:
+            artist_raw_id = artist["profile"]["artist_id"]
+            artist_albums = self.client.get_artist_albums(artist_raw_id,20,0)
+            for album in artist_albums:
                 self._download_album(album['encrypted_album_id'])
         else:
             self._download_album(self.id)
@@ -92,7 +94,10 @@ class Download():
     @logger.catch
     def _download_album(self, id):
         self.meta = self.client.get_album(id=id)
-        self.meta['release_date'] = self.client.get_date(id)
+        self.meta['release_date'] = self.meta['album']['album_date'].replace('-', '.')
+        # Include first day of month if not present
+        if len(self.meta['release_date']) == 7:
+            self.meta['release_date'] = self.meta['release_date'] + ".01"
         song_list = self.client.get_album_more(self.meta['album']['album_id'])
         self._create_album_folder()
         self._download_cover()
